% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print_and_plot.R
\name{plot.fitted_DAG}
\alias{plot.fitted_DAG}
\title{Plot a directed acyclic graph with path coefficients.}
\usage{
\method{plot}{fitted_DAG}(x, type = "width", labels = NULL,
  algorithm = "sugiyama", manual_layout = NULL, text_size = 6,
  box_x = 12, box_y = 8, edge_width = 1.25, curvature = 0.02,
  rotation = 0, flip_x = FALSE, flip_y = FALSE, arrow = grid::arrow(type
  = "closed", 18, grid::unit(15, "points")), colors = c("firebrick", "navy"),
  show.legend = TRUE, width_const = NULL, ...)
}
\arguments{
\item{x}{An object of class \code{fitted_DAG}.}

\item{type}{How to express the weight of the path. Either \code{"width"}, or \code{"color"}.}

\item{labels}{An optional set of labels to use for the nodes. This should be a named vector, of
the form \code{c(var1 = "label1", var2 = "label2")}.
If left at `NULL``, the variable names of the DAGs are used.}

\item{algorithm}{A layout algorithm from \code{igraph}, see
\code{\link[ggraph:create_layout]{ggraph::create_layout()}} and \code{\link[ggraph:create_layout.igraph]{ggraph::create_layout.igraph()}}. By default,
uses the Sugiyama layout algorithm, which is designed to minimize edge crossing in DAGs.}

\item{manual_layout}{Alternatively, precisely define the layout yourself, by providing a
\code{data.frame} that at least has a column \code{name} with all variable names, and columns \code{x} and \code{y}
with positions to be plotted. Setting this parameter overrides \code{algorithm} but other changes,
such as \code{rotation} and \code{flip}s will still be applied.}

\item{text_size}{Size of the node label text.}

\item{box_x}{To avoid the arrows colliding with the nodes, specify the
rectangular dimensions of an invisible box around each node. If you have
long labels, you need to increase this.}

\item{box_y}{To avoid the arrows colliding with the nodes, specify the
rectangular dimensions of an invisible box around each node. If you have
multi-line labels, you need to increase this.}

\item{edge_width}{Width of the edges.}

\item{curvature}{Curvature of the edges. A slight curvature can look pretty.}

\item{rotation}{Supply the degrees you want to rotate the layout by. This is useful in order to
put rotate your upstream nodes towards the top if needed.}

\item{flip_x}{Whether to flip the node positions horizontally.}

\item{flip_y}{Whether to flip the node positions vertically.}

\item{arrow}{A \code{grid::arrow} object, specifying the shape and size of the arrowheads.

The order of facets is taken from the ordering of the list, with the facet
labels coming from the names of the list. If the list is unnamed, sequential
lettering is used.}

\item{colors}{The end points of the continuous color scale. Keep in mind that red and green are
obvious colors to use, but are better to be avoided because of color blind users.}

\item{show.legend}{Whether a legend for the color scale should be shown.}

\item{width_const}{Deprecated.}

\item{...}{Not used.}
}
\description{
Plot a directed acyclic graph with path coefficients.
}
\examples{
  d <- DAG(LS ~ BM, NL ~ BM, DD ~ NL + LS)
  d_fitted <- est_DAG(d, rhino, rhino_tree, 'lambda')
  plot(d_fitted)
}
